Developer documentation
=======================

These objects are not relevant to front-end users, only NengoDL developers.

.. toctree::
    :maxdepth: 3

    builder
    op_builders
    tensor_graph
    signals
    graph_optimizer
    utils
